.. image:: https://img.shields.io/travis/nonameitem/cool-django-auth-ldap/master?style=flat-square
   :target: https://travis-ci.org/NoNameItem/cool-django-auth-ldap
.. image:: https://img.shields.io/coveralls/github/NoNameItem/cool-django-auth-ldap/master?style=flat-square
   :target: https://coveralls.io/github/NoNameItem/cool-django-auth-ldap
.. image:: https://img.shields.io/codeclimate/maintainability/NoNameItem/cool-django-auth-ldap?style=flat-square
   :target: https://codeclimate.com/github/NoNameItem/cool-django-auth-ldap
.. image:: https://img.shields.io/pypi/v/cool-django-auth-ldap?style=flat-square
   :target: https://pypi.org/project/cool-django-auth-ldap/
.. image:: https://img.shields.io/pypi/pyversions/cool-django-auth-ldap?style=flat-square
   :target: https://pypi.org/project/cool-django-auth-ldap/
.. image:: https://img.shields.io/pypi/djversions/cool-django-auth-ldap?style=flat-square
   :target: https://pypi.org/project/cool-django-auth-ldap/
